==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttp2RouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 */
public data class RouteSpecHttp2RouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttp2RouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class RouteSpecHttp2RouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("vtlecljwdpkauchp")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("bcxxbvtnohxvkisx")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): RouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        RouteSpecHttp2RouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttp2RouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact query parameter to match on.
 */
public data class RouteSpecHttp2RouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttp2RouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttp2RouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class RouteSpecHttp2RouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("wegixrsvwagfquwp")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("occdqilculyfysna")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): RouteSpecHttp2RouteMatchQueryParameterMatchArgs =
        RouteSpecHttp2RouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}
